==> afdko-2.8.3.tar.gz: afdko-2.8.3/c/tx/source/cff.h <==
"[-cff options: -E, -F, -O, -S, +T, +V, -Z, -b, -d]\n"
"+/-E    optimize for embedding\n"
"+/-F    optimize Family zones\n"
"+/-O    optimize for ROM\n"
"+/-S    subroutinize\n"
"+/-T    optimize charstrings\n"
"+/-V    remove path overlaps. Default is to not remove overlaps\n"
"+/-Z    do not/do decompose SEAC and dotsection operators\n",
"+/-b    preserve glyph order\n"
"+/-d    enable duplicate hintsubs warnings\n"
"-n      remove hints\n"
"-std    force the output font to have StandardEncoding\n"
"-no_futile remove futile subrs during subroutinization\n"
"\n"
"CFF mode writes a CFF conversion of an abstract font. The precise form of the\n"
"CFF font that is written can be controlled to a limited extent by the options\n",
"above. The feature is enabled by the + form of the option and disabled by the \n"
"- form of the option.\n"
"\n"
"The +E (embedding) option removes purely descriptive keys from the font without\n"
"affecting its rendering. The +F (Family) option removes FamilyBlues and\n"
"FamilyOtherBlues from hint dictionaries if they are identical to the BlueValues\n"
"and OtherBlues, respectively. The +O (optimize) option removes the same keys as\n"
"the +E option as well as performing some charstring optimizations that are\n",
"suitable for fonts embedded in printer ROMs. The +T (testing) option performs\n"
"charstring optimizations that are normally desirable but prevent bitmap\n"
"comparisons from being performed on some charstrings. These optimizations may\n"
"be disabled using the -T option. Note: +/-T implies +/-F. The -Z\n"
"option converts charstrings using the seac operator into a regular path by\n"
"combining the component glyphs specified in the charstring and removes the\n",
"dotsection operator. Normally glyphs are sorted to reduce the CFF data size.\n"
"The +b option forces the original glyph order to be preserved (with the\n"
"exception of the .notdef glyph which is always assigned glyph index 0). The +d\n"
"(debug) option enables duplicate hintsubrs warnings on stderr.\n"
"\n"
"For example, the command:\n"
"\n"
"    tx -cff +d -a rdr_____.pfb\n"
"\n"
"converts the font file \"rdr_____.pfb\" to CFF, with charstring warnings enabled,\n"
"and writes the results to the file \"rdr_____.cff\".\n"

==> afdko-3.0.0.tar.gz: afdko-3.0.0/c/tx/source/cff.h <==
"[-cff options: -E, -F, -O, -S, +T, +V, -Z, -b, -d]\n"
"+/-E    optimize for embedding\n"
"+/-F    optimize Family zones\n"
"+/-O    optimize for ROM\n"
"+/-S    subroutinize\n"
"+/-T    optimize charstrings\n"
"+/-V    remove path overlaps. Default is to not remove overlaps\n"
"+/-Z    do not/do decompose SEAC and dotsection operators\n",
"+/-b    preserve glyph order\n"
"+/-d    enable duplicate hintsubs warnings\n"
"-n      remove hints\n"
"-std    force the output font to have StandardEncoding\n"
"-no_futile remove futile subrs during subroutinization (deprecated; always in effect)\n"
"\n"
"CFF mode writes a CFF conversion of an abstract font. The precise form of the\n"
"CFF font that is written can be controlled to a limited extent by the options\n",
"above. The feature is enabled by the + form of the option and disabled by the \n"
"- form of the option.\n"
"\n"
"The +E (embedding) option removes purely descriptive keys from the font without\n"
"affecting its rendering. The +F (Family) option removes FamilyBlues and\n"
"FamilyOtherBlues from hint dictionaries if they are identical to the BlueValues\n"
"and OtherBlues, respectively. The +O (optimize) option removes the same keys as\n"
"the +E option as well as performing some charstring optimizations that are\n",
"suitable for fonts embedded in printer ROMs. The +T (testing) option performs\n"
"charstring optimizations that are normally desirable but prevent bitmap\n"
"comparisons from being performed on some charstrings. These optimizations may\n"
"be disabled using the -T option. Note: +/-T implies +/-F. The -Z\n"
"option converts charstrings using the seac operator into a regular path by\n"
"combining the component glyphs specified in the charstring and removes the\n",
"dotsection operator. Normally glyphs are sorted to reduce the CFF data size.\n"
"The +b option forces the original glyph order to be preserved (with the\n"
"exception of the .notdef glyph which is always assigned glyph index 0). The +d\n"
"(debug) option enables duplicate hintsubrs warnings on stderr.\n"
"\n"
"For example, the command:\n"
"\n"
"    tx -cff +d -a rdr_____.pfb\n"
"\n"
"converts the font file \"rdr_____.pfb\" to CFF, with charstring warnings enabled,\n"
"and writes the results to the file \"rdr_____.cff\".\n"
